@@ -95,6 +95,8 @@ struct _EphyWebView {
   GSList *hidden_popups;
   GSList *shown_popups;
 
+  GtkWidget *geolocation_info_bar;
+  GtkWidget *notification_info_bar;
   GtkWidget *password_info_bar;
 
   EphyHistoryService *history_service;
@@ -479,6 +481,26 @@ ephy_web_view_button_press_event (GtkWidget *widget, GdkEventButton *event)
   return GTK_WIDGET_CLASS (ephy_web_view_parent_class)->button_press_event (widget, event);
 }
 
+static void
+ephy_web_view_track_info_bar (GtkWidget  *new_info_bar,
+                              GtkWidget **tracked_info_bar)
+{
+  g_assert (GTK_IS_INFO_BAR (new_info_bar));
+  g_assert (tracked_info_bar);
+  g_assert (!*tracked_info_bar || GTK_IS_INFO_BAR (*tracked_info_bar));
+
+  /* We track info bars so we only ever show one of a kind. */
+  if (*tracked_info_bar) {
+    g_object_remove_weak_pointer (G_OBJECT (*tracked_info_bar),
+                                  (gpointer *)tracked_info_bar);
+    gtk_widget_destroy (*tracked_info_bar);
+  }
+
+  *tracked_info_bar = new_info_bar;
+  g_object_add_weak_pointer (G_OBJECT (new_info_bar),
+                             (gpointer *)tracked_info_bar);
+}
+
 static GtkWidget *
 ephy_web_view_create_form_auth_save_confirmation_info_bar (EphyWebView *web_view,
                                                            const char  *hostname,
@@ -514,17 +536,11 @@ ephy_web_view_create_form_auth_save_confirmation_info_bar (EphyWebView *web_view
   gtk_container_add (GTK_CONTAINER (content_area), label);
   gtk_widget_show (label);
 
+  ephy_web_view_track_info_bar (info_bar, &web_view->password_info_bar);
+
   ephy_embed_add_top_widget (EPHY_GET_EMBED_FROM_EPHY_WEB_VIEW (web_view),
                              info_bar, FALSE);
 
-  /* We track the info_bar, so we only ever show one */
-  if (web_view->password_info_bar)
-    gtk_widget_destroy (web_view->password_info_bar);
-
-  web_view->password_info_bar = info_bar;
-  g_object_add_weak_pointer (G_OBJECT (info_bar),
-                             (gpointer *)&web_view->password_info_bar);
-
   return info_bar;
 }
 
@@ -757,6 +773,16 @@ ephy_web_view_dispose (GObject *object)
     view->web_extension = NULL;
   }
 
+  if (view->geolocation_info_bar) {
+    g_object_remove_weak_pointer (G_OBJECT (view->geolocation_info_bar), (gpointer *)&view->geolocation_info_bar);
+    view->geolocation_info_bar = NULL;
+  }
+
+  if (view->notification_info_bar) {
+    g_object_remove_weak_pointer (G_OBJECT (view->notification_info_bar), (gpointer *)&view->notification_info_bar);
+    view->notification_info_bar = NULL;
+  }
+
   if (view->password_info_bar) {
     g_object_remove_weak_pointer (G_OBJECT (view->password_info_bar), (gpointer *)&view->password_info_bar);
     view->password_info_bar = NULL;
@@ -1290,6 +1316,11 @@ permission_request_cb (WebKitWebView           *web_view,
                     G_CALLBACK (decide_on_permission_request),
                     g_object_ref (decision));
 
+  if (WEBKIT_IS_GEOLOCATION_PERMISSION_REQUEST (decision))
+    ephy_web_view_track_info_bar (info_bar, &EPHY_WEB_VIEW (web_view)->geolocation_info_bar);
+  else
+    ephy_web_view_track_info_bar (info_bar, &EPHY_WEB_VIEW (web_view)->notification_info_bar);
+
   ephy_embed_add_top_widget (EPHY_GET_EMBED_FROM_EPHY_WEB_VIEW (web_view),
                              info_bar, TRUE);
 
@@ -1427,7 +1458,7 @@ update_security_status_for_committed_load (EphyWebView *view,
   g_clear_object (&view->certificate);
   g_clear_pointer (&view->tls_error_failing_uri, g_free);
 
-  if (webkit_security_manager_uri_scheme_is_local (security_manager, soup_uri->scheme)) {
+  if (!soup_uri || webkit_security_manager_uri_scheme_is_local (security_manager, soup_uri->scheme)) {
     security_level = EPHY_SECURITY_LEVEL_LOCAL_PAGE;
   } else if (webkit_web_view_get_tls_info (WEBKIT_WEB_VIEW (view), &view->certificate, &view->tls_errors)) {
     g_object_ref (view->certificate);
@@ -1439,7 +1470,8 @@ update_security_status_for_committed_load (EphyWebView *view,
 
   ephy_web_view_set_security_level (view, security_level);
 
-  soup_uri_free (soup_uri);
+  if (soup_uri)
+    soup_uri_free (soup_uri);
 }
 
 static void
@@ -1873,16 +1905,13 @@ load_failed_cb (WebKitWebView  *web_view,
   view->load_failed = TRUE;
   ephy_web_view_set_link_message (view, NULL);
 
-  if (error->domain == SOUP_HTTP_ERROR ||
-      error->domain == G_TLS_ERROR) {
+  if (error->domain != WEBKIT_NETWORK_ERROR &&
+      error->domain != WEBKIT_POLICY_ERROR &&
+      error->domain != WEBKIT_PLUGIN_ERROR) {
     ephy_web_view_load_error_page (view, uri, EPHY_WEB_VIEW_ERROR_PAGE_NETWORK_ERROR, error);
     return TRUE;
   }
 
-  g_return_val_if_fail ((error->domain == WEBKIT_NETWORK_ERROR) ||
-                        (error->domain == WEBKIT_POLICY_ERROR) ||
-                        (error->domain == WEBKIT_PLUGIN_ERROR), FALSE);
-
   switch (error->code) {
     case WEBKIT_NETWORK_ERROR_FAILED:
     case WEBKIT_NETWORK_ERROR_TRANSPORT:
@@ -2110,8 +2139,11 @@ ephy_web_view_new (void)
 GtkWidget *
 ephy_web_view_new_with_related_view (WebKitWebView *related_view)
 {
+  EphyEmbedShell *shell = ephy_embed_shell_get_default ();
+
   return g_object_new (EPHY_TYPE_WEB_VIEW,
                        "related-view", related_view,
+                       "user-content-manager", ephy_embed_shell_get_user_content_manager (shell),
                        "settings", ephy_embed_prefs_get_settings (),
                        NULL);
 }
